# -*- rpm-spec -*-

# Default to skipping autoreconf.  Distros can change just this one line
# (or provide a command-line override) if they backport any patches that
# touch configure.ac or Makefile.am.
%{!?enable_autotools:%global enable_autotools 1}

# The hypervisor drivers that run in libvirtd
%define with_qemu          0%{!?_without_qemu:1}
%define with_lxc           0%{!?_without_lxc:0}
%define with_libxl         0%{!?_without_libxl:0}
%define with_vbox          0%{!?_without_vbox:0}

%define with_qemu_tcg      %{with_qemu}

%define qemu_kvm_arches %{ix86} x86_64 aarch64

%ifarch %{qemu_kvm_arches}
    %define with_qemu_kvm      %{with_qemu}
%else
    %define with_qemu_kvm      0
%endif

%if ! %{with_qemu_tcg} && ! %{with_qemu_kvm}
    %define with_qemu 0
%endif

# Then the hypervisor drivers that run outside libvirtd, in libvirt.so
%define with_openvz        0%{!?_without_openvz:0}
%define with_vmware        0%{!?_without_vmware:0}
%define with_esx           0%{!?_without_esx:0}
%define with_hyperv        0%{!?_without_hyperv:0}

# Then the secondary host drivers, which run inside libvirtd
%define with_storage_rbd      0%{!?_without_storage_rbd:1}
%define with_storage_sheepdog 0%{!?_without_storage_sheepdog:0}
%define with_storage_gluster 0%{!?_without_storage_gluster:1}

%define with_numactl          0%{!?_without_numactl:1}

# Numactl is not available on many non-x86 archs
%ifarch %{arm} riscv64
    %define with_numactl 0
%endif

%define with_storage_zfs      0%{!?_without_storage_zfs:1}
%ifarch aarch64 x86_64
    %define with_storage_zfs 0
%endif

%define arg_dtrace --without-dtrace

# We need a recent enough libiscsi (>= 1.18.0)
%define with_storage_iscsi_direct 0%{!?_without_storage_iscsi_direct:1}

# A few optional bits off by default, we enable later
%define with_fuse          0%{!?_without_fuse:0}
%define with_sanlock       0%{!?_without_sanlock:1}
%define with_numad         0%{!?_without_numad:0}
%define with_firewalld     0%{!?_without_firewalld:1}
%define with_firewalld_zone 0%{!?_without_firewalld_zone:1}
%define with_libssh2       0%{!?_without_libssh2:1}
%define with_wireshark     0%{!?_without_wireshark:1}
%define with_libssh        0%{!?_without_libssh:1}
%define with_bash_completion  0%{!?_without_bash_completion:1}

# Finally set the OS / architecture specific special cases

# Xen is available only on i386 x86_64 ia64
%ifnarch %{ix86} x86_64 ia64
    %define with_libxl 0
%endif

# vbox is available only on i386 x86_64
%ifnarch %{ix86} x86_64
    %define with_vbox 0
%endif

%define with_bash_completion  0%{!?_without_bash_completion:1}

# Enable wireshark plugins for all distros shipping libvirt 1.2.2 or newer
%define wireshark_plugindir %(pkg-config --variable plugindir wireshark)/epan

%if %{with_qemu} || %{with_lxc}
# numad is used to manage the CPU and memory placement dynamically,
# it's not available on many non-x86 architectures.
    %ifnarch s390 s390x %{arm} riscv64
        %define with_numad    0%{!?_without_numad:1}
    %endif
%endif

# Force QEMU to run as non-root
%define qemu_user  qemu
%define qemu_group  qemu

%define enable_werror --enable-werror

%define tls_priority "@LIBVIRT,SYSTEM"


Summary: Library providing a simple virtualization API
Name: libvirt
Version: 6.2.0
Release: 49
License: LGPLv2+
URL: https://libvirt.org/

%if %(echo %{version} | grep -q "\.0$"; echo $?) == 1
    %define mainturl stable_updates/
%endif
Source: https://libvirt.org/sources/%{?mainturl}libvirt-%{version}.tar.xz
Patch0000: libvirt-qemu-fix-potential-memory-leak.patch
Patch0001: libvirt-qemu-add-pointer-check-in-qemuMonitorLastError.patch
Patch0002: libvirt-qemu-fix-a-concurrent-operation-situation.patch
Patch0003: libvirt-cgroup-cleanup-eventParams-when-virTypedParamsAddULL.patch
Patch0004: libvirt-nodedev-fix-potential-heap-use-after-free.patch
Patch0005: libvirt-po-Refresh-translation-for-running-state.patch
Patch0006: libvirt-cpu_map-Introduce-arm-CPU-models.patch
Patch0007: libvirt-cpu-introduce-virCPUarmData-to-virCPUData.patch
Patch0008: libvirt-cpu-arm-add-cpu-data-free-function-to-virCPUarmDataF.patch
Patch0009: libvirt-cpu-arm-add-load-cpu-map-parse-function.patch
Patch0010: libvirt-cpu-arm-add-decode-function.patch
Patch0011: libvirt-cpu-arm-add-virCPUarmGetHost-implment.patch
Patch0012: libvirt-cpu-arm-implment-cpu-baseline-function.patch
Patch0013: libvirt-cpu-arm-implment-cpu-compare-function.patch
Patch0014: libvirt-tests-add-cpu-compare-test-cases-for-arm-CPU.patch
Patch0015: libvirt-tests-add-baseline-test-cases-for-arm-CPU.patch
Patch0016: libvirt-util-virdaemon-fix-waiting-for-child-processes.patch
Patch0017: libvirt-virsh-Fix-return-code-for-dump-and-migrate.patch
Patch0018: libvirt-virsh-Fix-return-code-for-dump.patch
Patch0019: libvirt-cpu-aarch64-enable-host-model-cpu-for-AArch64-archit.patch
Patch0020: libvirt-cpu_map-add-kunpeng-920-features-as-known-features.patch
Patch0021: libvirt-Substitute-security_context_t-with-char.patch
Patch0022: libvirt-conf-Don-t-format-http-cookies-unless-VIR_DOMAIN_DEF.patch
Patch0023: libvirt-virstoragetest-testBackingParse-Use-VIR_DOMAIN_DEF_F.patch
Patch0024: libvirt-support-aarch64-vtpm-with-parameter-tpm-tis-.patch
Patch0025: libvirt-tests-commandtest-skip-the-test4-if-the-testcase-is-.patch
Patch0026: libvirt-remote-fix-driver-name-check-for-libxl-driver.patch
Patch0027: libvirt-systemd-start-libvirtd-after-firewalld-iptables-serv.patch
Patch0028: libvirt-qemuDomainCleanupRun-Actually-run-cleanup-callbacks-.patch
Patch0029: libvirt-virDevMapperGetTargetsImpl-quit-early-if-device-is-n.patch
Patch0030: libvirt-qemu-only-stop-external-devices-after-the-domain.patch
Patch0031: libvirt-qemuDomainStorageSourcePrivateDispose-Free-httpcooki.patch
Patch0032: libvirt-Don-t-require-secdrivers-to-implement-.domainMoveIma.patch
Patch0033: libvirt-qemuProcessStop-Use-XATTRs-to-restore-seclabels-on-d.patch
Patch0034: libvirt-qemuProcessStop-Reattach-NVMe-disks-a-domain-is-mirr.patch
Patch0035: libvirt-security-don-t-fail-if-built-without-attr-support.patch
Patch0036: libvirt-qemu-Skip-pre-creation-of-NVMe-disks.patch
Patch0037: libvirt-Fix-some-wrong-usage-of-ATTRIBUTE_NONNULL.patch
Patch0038: libvirt-conf-Increase-cpuset-length-limit-for-CPU-pinning.patch
Patch0039: libvirt-virQEMUDriverConfigNew-Add-slash-to-cfg-defaultTLSx5.patch
Patch0040: libvirt-qemuDomainSetNumaParamsLive-set-nodeset-for-root-cgr.patch
Patch0041: libvirt-qemu-do-not-add-model-when-actual-iface-type-is-host.patch
Patch0042: libvirt-qemu-pre-create-the-dbus-directory-in-qemuStateIniti.patch
Patch0043: libvirt-conf-vmx-check-for-OOM-after-calling-xmlBufferCreate.patch
Patch0044: libvirt-leaseshelper-Wait-to-acquire-PID-file.patch
Patch0045: libvirt-leaseshelper-Report-more-errors.patch
Patch0046: libvirt-qemuBuildMemoryBackendProps-Use-boolean-type-for-pme.patch
Patch0047: libvirt-qemu-format-ramfb-attribute-for-mediated-devices.patch
Patch0048: libvirt-resctrl-Do-not-open-directory-for-writing.patch
Patch0049: libvirt-libxl-fix-crash-when-initializing-driver.patch
Patch0050: libvirt-util-fix-iteration-in-virSocketAddrResolveService.patch
Patch0051: libvirt-qemu-fix-hang-in-p2p-xbzrle-compression-parallel-mig.patch
Patch0052: libvirt-qemu-Revoke-access-to-mirror-on-failed-blockcopy.patch
Patch0053: libvirt-qemuDomainDefPostParse-Fail-if-unable-to-fill-machin.patch
Patch0054: libvirt-virNetDevGetFamilyId-Change-signature.patch
Patch0055: libvirt-virNetDevSwitchdevFeature-Make-failure-to-get-family.patch
Patch0056: libvirt-qemuDomainGetUnplugTimeout-Add-G_GNUC_NO_INLINE.patch
Patch0057: rpc-gendispatch-handle-empty-flags.patch
Patch0058: rpc-add-support-for-filtering-acls-by-uint-params.patch
Patch0059: rpc-require-write-acl-for-guest-agent-in-virDomainIn.patch
Patch0060: qemu-agent-set-ifname-to-NULL-after-freeing.patch
Patch0061: util-Move-virIsDevMapperDevice-to-virdevmapper.c.patch
Patch0062: virdevmapper-Don-t-use-libdevmapper-to-obtain-depend.patch
Patch0063: libvirt-Add-retry-support-for-error-policy.patch
Patch0064: qemu-Support-retry-BLOCK_IO_ERROR-event.patch
Patch0065: add-phytium-2000plus-and-s2500-support-on-arm-archit.patch
Patch0066: libvirt-conf-Set-default-values-of-retry-fileds.patch
Patch0067: tests-fix-stat-mocking-with-Fedora-rawhide.patch
Patch0068: cpu_map-Add-Cooperlake-x86-CPU-model.patch
Patch0069: cpu_map-Add-pschange-mc-no-bit-in-IA32_ARCH_CAPABILI.patch
Patch0070: cpu_map-Distribute-x86_Cooperlake.xml.patch
Patch0071: Don-t-cache-device-mapper-major.patch
Patch0072: virdevmapper-Handle-kernel-without-device-mapper-sup.patch
Patch0073: virDevMapperGetTargets-Don-t-ignore-EBADF.patch
Patch0074: conf-domain_conf-pin-the-retry_interval-and-retry_ti.patch
Patch0075: storage_driver-Unlock-object-on-ACL-fail-in-storageP.patch
Patch0076: security-fix-SELinux-label-generation-logic.patch
Patch0077: Hotpatch-introduce-DomainHotpatchManage-API.patch
Patch0078: hotpatch-Implement-qemuDomainHotpatchManage.patch
Patch0079: hotpatch-introduce-hotpatch-async-job-flag.patch
Patch0080: hotpatch-implement-hotpatch-virsh-api.patch
Patch0081: hotpatch-check-vm-id-and-pid-before-using-hotpatch-a.patch
Patch0082: domain-add-logs-for-virDomainHotpatchManage.patch
Patch0083: docs-build-Don-t-include-stylesheet-in-intermediate-.patch
Patch0084: tests-Replace-deprecated-ASN1-code.patch
Patch0085: tests-disabale-storage-tests.patch
Patch0086: Revert-tests-disabale-storage-tests.patch
Patch0087: hotpatch-virsh-support-autoload-mode.patch
Patch0088: virQEMUBuildCommandLineJSON-Allow-skipping-certain-k.patch
Patch0089: virQEMUBuildCommandLineJSON-Add-possibility-for-usin.patch
Patch0090: util-virqemu-Introduce-virQEMUBuildNetdevCommandline.patch
Patch0091: util-json-Introduce-virJSONValueObjectAppendStringPr.patch
Patch0092: qemuBuildChannelsCommandLine-Use-typecasted-switch-f.patch
Patch0093: qemuBuildChannelsCommandLine-Extract-common-formatti.patch
Patch0094: qemuBuildChannelChrDeviceStr-Remove-formatting-of-pr.patch
Patch0095: qemuMonitorJSON-Add-Remove-Netdev-Refactor-cleanup.patch
Patch0096: qemuBuildHostNetStr-Stop-using-ipv6-net-convenience-.patch
Patch0097: qemu-command-Generate-netdev-command-line-via-JSON-c.patch
Patch0098: qemuBuildChannelGuestfwdNetdevProps-Convert-to-gener.patch
Patch0099: qemuMonitorAddNetdev-Convert-to-the-native-JSON-prop.patch
Patch0100: virCommand-Introduce-virCommandGetArgList.patch
Patch0101: testutilsqemuschema-Introduce-testQEMUSchemaValidate.patch
Patch0102: testCompareXMLToArgv-Split-out-preparation-and-comma.patch
Patch0103: virQEMUBuildNetdevCommandlineFromJSON-Prepare-for-qu.patch
Patch0104: qemu-Prepare-for-testing-of-netdev_add-props-via-qem.patch
Patch0105: qemuxml2argvtest-Add-QAPI-QMP-schema-validation-for-.patch
Patch0106: qemu-Probe-for-a-few-params-supported-by-migrate-set.patch
Patch0107: qemu-Avoid-deprecated-migrate_set_speed-QMP-command.patch
Patch0108: qemu-Avoid-deprecated-migrate_set_downtime-QMP-comma.patch
Patch0109: qemu-Avoid-deprecated-query-migrate-cache-size-QMP-c.patch
Patch0110: qemu-Avoid-deprecated-migrate-set-cache-size-QMP-com.patch
Patch0111: qemu-Track-numa-mem-supported-machine-attribute.patch
Patch0112: qemuBuildNumaArgStr-Switch-order-of-if-and-for.patch
Patch0113: qemuBuildNumaArgStr-Use-modern-numa-memdev-if-old-nu.patch
Patch0114: Revert-libvirt-support-aarch64-vtpm-with-parameter-t.patch
Patch0115: qemu-Fix-swtpm-device-with-aarch64.patch
Patch0116: qemu-Fix-libvirt-hang-due-to-early-TPM-device-stop.patch
Patch0117: qemu_tpm-Move-logfile-path-generation-into-a-separat.patch
Patch0118: qemu_tpm-Generate-log-file-path-among-with-storage-p.patch
Patch0119: virtpm-Fix-path-handling-in-virTPMEmulatorInit.patch
Patch0120: qemuMonitorJSONSetMigrationParams-Take-double-pointe.patch
Patch0121: qemuMonitorJSONAddObject-Take-double-pointer-for-pro.patch
Patch0122: qemuMonitorJSONMakeCommandInternal-Clear-arguments-w.patch
Patch0123: qemuMonitorAddObject-Fix-semantics-of-alias.patch
Patch0124: qemuMonitorAddObject-Refactor-cleanup.patch
Patch0125: util-json-Replace-virJSONValueObjectSteal-by-virJSON.patch
Patch0126: qemu-command-Generate-commandline-of-masterKey0-secr.patch
Patch0127: qemu-command-Generate-commandline-of-sev0-sev-guest-.patch
Patch0128: qemu-command-Generate-commandline-of-iothread-object.patch
Patch0129: qemu-capabilities-Introduce-QEMU_CAPS_OBJECT_QAPIFIE.patch
Patch0130: qemu-monitor-Make-wrapping-of-props-of-object-add-op.patch
Patch0131: qemuMonitorCreateObjectPropsWrap-Open-code-in-qemuBu.patch
Patch0132: qemu-monitor-Don-t-add-props-wrapper-if-qemu-has-QEM.patch
Patch0133: qemu-command-Use-JSON-for-QAPIfied-object-directly.patch
Patch0134: tests-qemuxml2argv-Validate-generation-of-JSON-props.patch
Patch0135: qemu-capabilities-Enable-detection-of-QEMU_CAPS_OBJE.patch
Patch0136: apparmor-Permit-new-capabilities-required-by-libvirt.patch
Patch0137: virsh-Display-vhostuser-socket-path-in-domblklist.patch
Patch0138: sw_64-Add-sw64-architecture-support.patch
Patch0139: src-workaround-warning-triggered-in-glib-2.69.patch
Patch0140: nwfilter-fix-crash-when-counting-number-of-network-f.patch
Patch0141: apibuild-Fix-self.waring-method-call.patch
Patch0142: qemu-Add-missing-lock-in-qemuProcessHandleMonitorEOF.patch
Patch0143: util-avoid-race-in-releasing-the-GSource-in-event-th.patch
Patch0144: test-Fix-memory-leak-in-testParseXMLDocFromFile.patch
Patch0145: lxc-Fix-memory-leak-in-virLXCControllerPopulateDevic.patch
Patch0146: util-Fix-memory-leak-in-virAuthConfigLookup.patch
Patch0147: util-Fix-memory-leak-in-virAuthGetCredential.patch
Patch0148: qemu_security-Complete-renaming-of-virSecurityManage.patch
Patch0149: virSecurityManagerMetadataLock-Ignore-RO-filesystem.patch
Patch0150: virSecurityManagerMetadataLock-Clarify-directory-loc.patch
Patch0151: qemu-Use-qemuSecurityDomainSetPathLabel-to-set-secla.patch
Patch0152: qemu-Drop-unused-qemuSecuritySetSavedStateLabel.patch
Patch0153: qemu-don-t-shutdown-event-thread-in-monitor-EOF-call.patch
Patch0154: cpu_map-Fix-Icelake-Server-model-number.patch
Patch0155: rpc-avoid-crash-when-system-time-jump-back.patch
Patch0156: check-for-NULL-before-calling-g_regex_unref.patch
Patch0157: qemu_monitor-Document-qemuMonitorUnregister.patch
Patch0158: storageBackendProbeTarget-Don-t-fail-if-backing-stor.patch
Patch0159: virPipeImpl-Don-t-overwrite-error.patch
Patch0160: virBufferAdd-Ensure-that-the-buffer-is-initialized-a.patch
Patch0161: qemuMigrationSrcRun-Don-t-jump-to-exit_monitor-from-.patch
Patch0162: util-Fix-error-reporting-in-virnetlink.patch
Patch0163: locking-Resolve-mem-leak-in-virLockDaemonPreExecRest.patch
Patch0164: qemu_conf-Fix-double-free-problem-for-cfg-firmwares.patch
Patch0165: qemuDomainCheckpointLoad-Don-t-align-disks-when-rest.patch
Patch0166: leaseshelper-Report-errors-on-failure.patch
Patch0167: networkGetDHCPLeases-Use-VIR_APPEND_ELEMENT-instead-.patch
Patch0168: qemuFirmwareFillDomain-Fill-NVRAM-template-on-migrat.patch
Patch0169: disk-storage-fix-allocation-size-for-pool-format-dos.patch
Patch0170: qemu-qemuDomainPMSuspendAgent-Don-t-assign-to-ret-in.patch
Patch0171: tests-avoid-close-of-bad-file-handle-in-commandtest.patch
Patch0172: util-event-check-return-value-of-virInitialize.patch
Patch0173: rpc-socket-properly-call-virSetCloseExec.patch
Patch0174: virsh-do-not-return-bool-in-virshNetworkPortUUIDComp.patch
Patch0175: logging-fix-endless-loop-on-EOF.patch
Patch0176: vircommand.c-write-child-pidfile-before-process-tuni.patch
Patch0177: virsocketaddr-Zero-netmask-in-virSocketAddrPrefixToN.patch
Patch0178: logging-read-all-bytes-on-EOF-in-event-handler.patch
Patch0179: libvirt-ensure-defresult-is-used-in-virConnectAuthCa.patch
Patch0180: qemu-firmware-check-virJSONValueObjectGet-return-val.patch
Patch0181: qemu-qemuDomainPMSuspendForDuration-Check-availabili.patch
Patch0182: virNodeDevPCICapSRIOVVirtualParseXML-fix-memleak-of-.patch
Patch0183: qemu-snapshot-Collect-query-named-block-nodes-prior-.patch
Patch0184: virsh-completer-use-signed-variable-for-XPathNodeSet.patch
Patch0185: virt-login-shell-correctly-calculate-string-length.patch
Patch0186: qemu-avoid-maybe-uninitialized-warning-by-GCC-10.patch
Patch0187: tools-avoid-potential-null-pointer-dereference-by-GC.patch
Patch0188: storage-avoid-maybe-uninitialized-warning-by-GCC-10.patch
Patch0189: virnuma-Don-t-work-around-numa_node_to_cpus-for-non-.patch
Patch0190: virsh-guest-agent-timeout-set-default-value-for-opti.patch
Patch0191: conf-properly-clear-out-autogenerated-macvtap-names-.patch
Patch0192: storage_util-fix-qemu-img-sparse-allocation.patch
Patch0193: vahDeinit-Fix-memory-leak.patch
Patch0194: virnetdevbridge-Ignore-EEXIST-when-adding-an-entry-t.patch
Patch0195: securityselinuxhelper-Fix-retval-of-setcon_raw-and-s.patch
Patch0196: virCapabilitiesHostNUMAInitReal-Free-cpus-properly.patch
Patch0197: vsh-fix-memory-leak-in-vshCommandParse.patch
Patch0198: qemu_interface-Fix-cfg-refcounting-in-qemuInterfaceP.patch
Patch0199: qemuBlockJobProcessEventCompletedPull-Avoid-dangling.patch
Patch0200: qemuBlockJobProcessEventCompletedPull-Add-backingSto.patch
Patch0201: nodedev-Signal-initCond-with-driver-locked.patch
Patch0202: nodedev-Mark-device-initialization-complete-even-in-.patch
Patch0203: cmdCheckpointList-Fix-memory-leak.patch
Patch0204: cmdSnapshotList-Fix-memory-leak.patch
Patch0205: virshCheckpointListCollect-Do-not-pass-NULL-to-qsort.patch
Patch0206: qemu-blockjob-Transition-into-ready-state-only-from-.patch
Patch0207: qemu-fix-crash-in-qemuDomainSetBlkioParameters-witho.patch
Patch0208: domain_capabilities-Assert-enums-fit-into-unsigned-i.patch
Patch0209: domain_conf.c-do-not-leak-video-in-virDomainDefParse.patch
Patch0210: conf-Use-unsigned-long-long-for-timer-frequency.patch
Patch0211: parthelper-Don-t-leak-canonical_path.patch
Patch0212: parthelper-Initialize-error-object.patch
Patch0213: qemu-fix-qemuMigrationSrcCleanup-to-use-qemuMigratio.patch
Patch0214: util-Avoid-double-free-in-virProcessSetAffinity.patch
Patch0215: util-fix-very-old-bug-typo-in-virNetDevParseVfInfo.patch
Patch0216: domain_conf-fix-NULL-dereference-on-error-in-virDoma.patch
Patch0217: testutils-call-va_end-before-return.patch
Patch0218: qemu-Don-t-cache-domCaps-in-virQEMUDriverGetDomainCa.patch
Patch0219: network-Introduce-mutex-for-bridge-name-generation.patch
Patch0220: hostdev-Update-mdev-pointer-reference-after-checking.patch
Patch0221: hostdev-mdev-Lookup-mdevs-by-sysfs-path-rather-than-.patch
Patch0222: util-new-function-virSkipToDigit.patch
Patch0223: util-Skip-over-any-extra-verbiage-preceding-version-.patch
Patch0224: qemuMigrationSrcNBDStorageCopyReady-Use-ready-state-.patch
Patch0225: qemuBlockJobEventProcess-Always-clear-mirrorState-wh.patch
Patch0226: qemu-Fix-memstat-for-non-transitional-memballoon.patch
Patch0227: virsh-Fix-XPATH-in-virshDomainDeviceAliasCompleter.patch
Patch0228: virsh-domain-Fix-error-handling-of-pthread_sigmask.patch
Patch0229: qemu_driver-increase-recorded-counter-for-disk-block.patch
Patch0230: qemu_capabilities-Don-t-leak-str-in-virQEMUCapsLoadM.patch
Patch0231: qemu_process-Release-domain-seclabel-later-in-qemuPr.patch
Patch0232: nodedev-Don-t-crash-when-exiting-before-init-is-done.patch
Patch0233: domain_cgroup.c-update-domain-after-setting-blkio.we.patch
Patch0234: virCPUDefFindFeature-Make-first-argument-const-ptr.patch
Patch0235: qemuOpenFileAs-Move-into-util-virqemu.c.patch
Patch0236: Don-t-call-qsort-over-NULL.patch
Patch0237: virFileReadLimFD-Cast-maxlen-to-size_t-before-adding.patch
Patch0238: virnuma-Use-numa_nodes_ptr-when-checking-available-N.patch
Patch0239: testutils-Don-t-leak-testBitmap-and-failedTests.patch
Patch0240: tests-Don-t-leak-cpu-defs.patch
Patch0241: virsh-snapshot-Don-t-leak-then-in-cmdSnapshotList.patch
Patch0242: util-virIdentitySetCurrent-only-unref-the-old-identi.patch
Patch0243: vireventglib-Remove-handles-with-the-highest-priorit.patch
Patch0244: qemu-Do-not-pass-negative-ncpus-to-virCapabilitiesCl.patch
Patch0245: qemu_agent-Rework-domain-object-locking-when-opening.patch
Patch0246: util-virExec-may-blocked-by-reading-pipe-if-grandchi.patch
Patch0247: util-fix-cache-invalidation-of-swtpm-capabilities.patch
Patch0248: virnettlscontext-Drop-gnutls_dh_set_prime_bits.patch
Patch0249: virnettlscontext-Don-t-pass-static-key-length-to-gnu.patch
Patch0250: rpc-Fix-memory-leak-of-fds.patch
Patch0251: migration-dirtyrate-Introduce-virDomainStartDirtyRat.patch
Patch0252: migration-dirtyrate-Implement-qemuDomainStartDirtyRa.patch
Patch0253: migration-dirtyrate-Introduce-domdirtyrate-calc-virs.patch
Patch0254: migration-dirtyrate-Introduce-virDomainDirtyRateStat.patch
Patch0255: migration-dirtyrate-Implement-qemuMonitorQueryDirtyR.patch
Patch0256: migration-dirtyrate-Extend-dirtyrate-statistics-for-.patch
Patch0257: migration-dirtyrate-Introduce-command-virsh-domstats.patch
Patch0258: docs-Fix-template-matching-in-page.xsl.patch
Patch0259: vircgroupv1-fix-null-string-specifier-argument-in-vi.patch
Patch0260: qemu-fix-null-string-specifier-argument-in-qemuDomai.patch
Patch0261: qemu-fix-domain-start-with-corrupted-save-file.patch
Patch0262: qemu-fix-bad-indentation-for-qemuDomainNVRAMPathForm.patch
Patch0263: util-fix-syslog-facility-value.patch
Patch0264: util-set-facility-when-opening-syslog-channel.patch
Patch0265: qemu-fix-memleak-in-qemuDomainAttachDeviceLive.patch
Patch0266: mdev-Fix-daemon-crash-when-reattaching-mdevs-on-assi.patch
Patch0267: Fix-allocation-of-virDomainFSDef.patch
Patch0268: virsh-Fix-typo-of-metadata.patch
Patch0269: virsh-cmdBlock-Remove-error-prefix-for-an-empty-line.patch
Patch0270: vshtabletest-Fix-potential-memleak.patch
Patch0271: vircgroupv2devices-fix-counting-entries-in-BPF-map.patch
Patch0272: node_device_udev.h-Drop-unused-macro.patch
Patch0273: qemu-fix-conversion-specifier-in-qemuBuildVsockDevPr.patch
Patch0274: checkpoint-Fix-a-typo-of-comments.patch
Patch0275: qemu_driver-Fix-indentation-in-qemuDomainGetStatsVcp.patch
Patch0276: vmx-Require-networkName-for-bridged-and-custom-NICs.patch
Patch0277: nodedev-wait-a-bit-longer-for-new-node-devices.patch
Patch0278: bash-completion-fix-variable-leaks-of-word.patch
Patch0279: util-Drop-pointless-NUL_TERMINATE-macro.patch
Patch0280: virDomainCheckpointCreateXML-Don-t-use-HTML-in-funct.patch
Patch0281: qemuMigrationSrcWaitForSpice-Remove-return-value.patch
Patch0282: virsh-cmdScreenshot-fix-cbdata-passing-to-virshStrea.patch
Patch0283: client-fix-memory-leak-in-client-msg.patch
Patch0284: tests-Fix-false-positive-in-testConfRoundTrip.patch
Patch0285: hyperv-fix-the-number-of-threads-per-core.patch
Patch0286: virCgroupKillRecursive-Return-1-on-failure-condition.patch
Patch0287: tests-Fix-lstat-mock-initialization-on-macOS.patch
Patch0288: storagepoolxml2argvtest-Reorder-gluster-arguments.patch
Patch0289: libvirt-guests-Sync-time-for-autostarted-guests.patch
Patch0290: cpu_ppc64-compare-CPU-function-is-ignoring-return-va.patch
Patch0291: security_util-Don-t-error-on-macOS-when-getting-sett.patch
Patch0292: vsh-Fix-completion-error-in-case-of-multiple-mac-add.patch
Patch0293: qemu-Do-not-require-TSC-frequency-to-strictly-match-.patch
Patch0294: qemu_alias-introduce-qemuDomainGetVhostUserAlias-hel.patch
Patch0295: docs-introduces-new-vhostuser-disk-type.patch
Patch0296: conf-implement-support-for-vhostuser-disk.patch
Patch0297: qemu_capabilities-introduce-vhost-user-blk-capabilit.patch
Patch0298: qemu-implement-vhost-user-blk-support.patch
Patch0299: qemu_command-remove-redundant-scsi-option-in-vhost-u.patch
Patch0300: lxc-fix-error-value-of-lxcNodeGetSecurityModel.patch
Patch0301: examples-hellolibvirt-fix-argc-check.patch
Patch0302: virsh-domain-fix-mistake-in-cmdMigrateSetMaxDowntime.patch
Patch0303: vbox_network-fix-possible-memory-leak-in-vboxNetwork.patch
Patch0304: lxc-Fix-syntax-error-in-lxcNodeGetSecurityModel.patch
Patch0305: qemu_command-Don-t-validate-accelerator-when-buildin.patch
Patch0306: qemu-Switch-to-accel.patch
Patch0307: tests-qemuxml2argvdata-qtests-switch-to-accel.patch
Patch0308: tests-Fix-vhostuser-args-file.patch
Patch0309: qemu_capabilities-Fix-incorrect-alignment.patch
Patch0310: qemu_driver-Acquire-MODIFY-job-in-qemuDomainStartDir.patch
Patch0311: qemu_capabilities-Introduce-QEMU_CAPS_CALC_DIRTY_RAT.patch
Patch0312: qemu_driver-Probe-capability-before-calculating-dirt.patch
Patch0313: qemu_capabilities-Introduce-QEMU_CAPS_DIRTYRATE_MODE.patch
Patch0314: include-Introduce-virDomainDirtyRateCalcFlags.patch
Patch0315: qemu_driver-Add-mode-parameter-to-qemuDomainStartDir.patch
Patch0316: update-the-Chinese-translation-of-nwfilter.patch
Patch0317: migration-migration-pin-add-some-migration-multiFd-p.patch
Patch0318: migration-migration-pin-add-qemu-monitor-callback-fu.patch
Patch0319: migration-migration-pin-add-migrationpin-for-migrati.patch
Patch0320: migration-migration-pin-add-domainMigrationPid-for-q.patch
Patch0321: migration-multifd-pin-add-qemu-monitor-callback-func.patch
Patch0322: migration-multifd-pin-support-migration-multifd-thre.patch

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-config-network = %{version}-%{release}
Requires: libvirt-daemon-config-nwfilter = %{version}-%{release}
%if %{with_libxl}
Requires: libvirt-daemon-driver-libxl = %{version}-%{release}
%endif
%if %{with_lxc}
Requires: libvirt-daemon-driver-lxc = %{version}-%{release}
%endif
%if %{with_qemu}
Requires: libvirt-daemon-driver-qemu = %{version}-%{release}
%endif
# We had UML driver, but we've removed it.
Obsoletes: libvirt-daemon-driver-uml <= 5.0.0
Obsoletes: libvirt-daemon-uml <= 5.0.0
%if %{with_vbox}
Requires: libvirt-daemon-driver-vbox = %{version}-%{release}
%endif
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}

Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-client = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

# All build-time requirements. Run-time requirements are
# listed against each sub-RPM
%if 0%{?enable_autotools}
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: gettext-devel
BuildRequires: libtool
%endif
BuildRequires: python3-docutils
BuildRequires: gcc
BuildRequires: perl-interpreter
BuildRequires: python3
BuildRequires: systemd-units
%if %{with_libxl}
BuildRequires: xen-devel
%endif
BuildRequires: glib2-devel >= 2.48
BuildRequires: libxml2-devel
BuildRequires: libxslt
BuildRequires: readline-devel
%if %{with_bash_completion}
BuildRequires: bash-completion >= 2.0
%endif
BuildRequires: ncurses-devel
BuildRequires: gettext
BuildRequires: libtasn1-devel
BuildRequires: gnutls-devel
BuildRequires: libattr-devel
# For pool-build probing for existing pools
BuildRequires: libblkid-devel >= 2.17
# for augparse, optionally used in testing
BuildRequires: augeas
BuildRequires: systemd-devel >= 185
BuildRequires: libpciaccess-devel >= 0.10.9
BuildRequires: yajl-devel
%if %{with_sanlock}
BuildRequires: sanlock-devel >= 2.4
%endif
BuildRequires: libpcap-devel >= 1.5.0
BuildRequires: libnl3-devel
BuildRequires: libselinux-devel
BuildRequires: dnsmasq >= 2.41
BuildRequires: iptables
BuildRequires: radvd
BuildRequires: ebtables
BuildRequires: module-init-tools
BuildRequires: cyrus-sasl-devel
BuildRequires: polkit >= 0.112
# For mount/umount in FS driver
BuildRequires: util-linux
%if %{with_qemu}
# For managing ACLs
BuildRequires: libacl-devel
# From QEMU RPMs
BuildRequires: /usr/bin/qemu-img
%endif
# For LVM drivers
BuildRequires: lvm2
# For pool type=iscsi
BuildRequires: iscsi-initiator-utils
%if %{with_storage_iscsi_direct}
# For pool type=iscsi-direct
BuildRequires: libiscsi-devel
%endif
# For disk driver
BuildRequires: parted-devel
# For Multipath support
BuildRequires: device-mapper-devel
# For XFS reflink clone support
BuildRequires: xfsprogs-devel
%if %{with_storage_rbd}
BuildRequires: librados-devel
BuildRequires: librbd-devel
%endif
%if %{with_storage_gluster}
BuildRequires: libgfapi0
BuildRequires: glusterfs-api-devel >= 3.4.1
BuildRequires: glusterfs-devel >= 3.4.1
%endif
%if %{with_storage_sheepdog}
BuildRequires: sheepdog
%endif
%if %{with_storage_zfs}
# Support any conforming implementation of zfs. On stock Fedora
# this is zfs-fuse, but could be zfsonlinux upstream RPMs
BuildRequires: /sbin/zfs
BuildRequires: /sbin/zpool
%endif
%if %{with_numactl}
# For QEMU/LXC numa info
BuildRequires: numactl-devel
%endif
BuildRequires: libcap-ng-devel >= 0.5.0
%if %{with_fuse}
BuildRequires: fuse-devel >= 2.8.6
%endif
%if %{with_libssh2}
BuildRequires: libssh2-devel >= 1.3.0
%endif

BuildRequires: netcf-devel >= 0.2.2
%if %{with_esx}
BuildRequires: libcurl-devel
%endif
%if %{with_hyperv}
BuildRequires: libwsman-devel >= 2.2.3
%endif
BuildRequires: audit-libs-devel
# we need /usr/sbin/dtrace
BuildRequires: systemtap-sdt-devel

# For mount/umount in FS driver
BuildRequires: util-linux
# For showmount in FS driver (netfs discovery)
BuildRequires: nfs-utils

# Communication with the firewall and polkit daemons use DBus
BuildRequires: dbus-devel

# Fedora build root suckage
BuildRequires: gawk

# For storage wiping with different algorithms
BuildRequires: scrub

%if %{with_numad}
BuildRequires: numad
%endif

%if %{with_wireshark}
BuildRequires: wireshark-devel >= 2.4.0
%endif

%if %{with_libssh}
BuildRequires: libssh-devel >= 0.7.0
%endif

BuildRequires: rpcgen
BuildRequires: libtirpc-devel

%if %{with_firewalld_zone}
BuildRequires: firewalld-filesystem
%endif

%description
Libvirt is a C toolkit to interact with the virtualization capabilities
of recent versions of Linux (and other OSes). The main package includes
the libvirtd server exporting the virtualization support.

%package docs
Summary: API reference and website documentation

%description docs
Includes the API reference for the libvirt C library, and a complete
copy of the libvirt.org website documentation.

%package daemon
Summary: Server side daemon and supporting files for libvirt library

# All runtime requirements for the libvirt package (runtime requrements
# for subpackages are listed later in those subpackages)

# The client side, i.e. shared libs are in a subpackage
Requires: %{name}-libs = %{version}-%{release}

# (client invokes 'nc' against the UNIX socket on the server)
Requires: /usr/bin/nc

# for modprobe of pci devices
Requires: module-init-tools

# for /sbin/ip & /sbin/tc
Requires: iproute
# tc is provided by iproute-tc since at least Fedora 26
Requires: iproute-tc

Requires: polkit >= 0.112
%ifarch %{ix86} x86_64 ia64
# For virConnectGetSysinfo
Requires: dmidecode
%endif
# For service management
Requires(post): systemd-units
Requires(post): systemd-sysv
Requires(preun): systemd-units
Requires(postun): systemd-units
%if %{with_numad}
Requires: numad
%endif
# libvirtd depends on 'messagebus' service
Requires: dbus
# For uid creation during pre
Requires(pre): shadow-utils

%description daemon
Server side daemon required to manage the virtualization capabilities
of recent versions of Linux. Requires a hypervisor specific sub-RPM
for specific drivers.

%package daemon-config-network
Summary: Default configuration files for the libvirtd daemon

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}

%description daemon-config-network
Default configuration files for setting up NAT based networking

%package daemon-config-nwfilter
Summary: Network filter configuration files for the libvirtd daemon

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}

%description daemon-config-nwfilter
Network filter configuration files for cleaning guest traffic

%package daemon-driver-network
Summary: Network driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: dnsmasq >= 2.41
Requires: radvd
Requires: iptables

%description daemon-driver-network
The network driver plugin for the libvirtd daemon, providing
an implementation of the virtual network APIs using the Linux
bridge capabilities.


%package daemon-driver-nwfilter
Summary: Nwfilter driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: iptables
Requires: ebtables

%description daemon-driver-nwfilter
The nwfilter driver plugin for the libvirtd daemon, providing
an implementation of the firewall APIs using the ebtables,
iptables and ip6tables capabilities


%package daemon-driver-nodedev
Summary: Nodedev driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
# needed for device enumeration
Requires: systemd >= 185

%description daemon-driver-nodedev
The nodedev driver plugin for the libvirtd daemon, providing
an implementation of the node device APIs using the udev
capabilities.


%package daemon-driver-interface
Summary: Interface driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: netcf-libs >= 0.2.2

%description daemon-driver-interface
The interface driver plugin for the libvirtd daemon, providing
an implementation of the network interface APIs using the
netcf library


%package daemon-driver-secret
Summary: Secret driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-secret
The secret driver plugin for the libvirtd daemon, providing
an implementation of the secret key APIs.

%package daemon-driver-storage-core
Summary: Storage driver plugin including base backends for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: nfs-utils
# For mkfs
Requires: util-linux
%if %{with_qemu}
# From QEMU RPMs
Requires: /usr/bin/qemu-img
%endif
%if !%{with_storage_rbd}
Obsoletes: libvirt-daemon-driver-storage-rbd < %{version}-%{release}
%endif

%description daemon-driver-storage-core
The storage driver plugin for the libvirtd daemon, providing
an implementation of the storage APIs using files, local disks, LVM, SCSI,
iSCSI, and multipath storage.

%package daemon-driver-storage-logical
Summary: Storage driver plugin for lvm volumes
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: lvm2

%description daemon-driver-storage-logical
The storage driver backend adding implementation of the storage APIs for block
volumes using lvm.


%package daemon-driver-storage-disk
Summary: Storage driver plugin for disk
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: parted
Requires: device-mapper

%description daemon-driver-storage-disk
The storage driver backend adding implementation of the storage APIs for block
volumes using the host disks.


%package daemon-driver-storage-scsi
Summary: Storage driver plugin for local scsi devices
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-storage-scsi
The storage driver backend adding implementation of the storage APIs for scsi
host devices.


%package daemon-driver-storage-iscsi
Summary: Storage driver plugin for iscsi
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: iscsi-initiator-utils

%description daemon-driver-storage-iscsi
The storage driver backend adding implementation of the storage APIs for iscsi
volumes using the host iscsi stack.


%if %{with_storage_iscsi_direct}
%package daemon-driver-storage-iscsi-direct
Summary: Storage driver plugin for iscsi-direct
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: libiscsi

%description daemon-driver-storage-iscsi-direct
The storage driver backend adding implementation of the storage APIs for iscsi
volumes using libiscsi direct connection.
%endif


%package daemon-driver-storage-mpath
Summary: Storage driver plugin for multipath volumes
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: device-mapper

%description daemon-driver-storage-mpath
The storage driver backend adding implementation of the storage APIs for
multipath storage using device mapper.


%if %{with_storage_gluster}
%package daemon-driver-storage-gluster
Summary: Storage driver plugin for gluster
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: glusterfs-client >= 2.0.1
Requires: /usr/sbin/gluster

%description daemon-driver-storage-gluster
The storage driver backend adding implementation of the storage APIs for gluster
volumes using libgfapi.
%endif


%if %{with_storage_rbd}
%package daemon-driver-storage-rbd
Summary: Storage driver plugin for rbd
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-storage-rbd
The storage driver backend adding implementation of the storage APIs for rbd
volumes using the ceph protocol.
%endif


%if %{with_storage_sheepdog}
%package daemon-driver-storage-sheepdog
Summary: Storage driver plugin for sheepdog
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: sheepdog

%description daemon-driver-storage-sheepdog
The storage driver backend adding implementation of the storage APIs for
sheepdog volumes using.
%endif


%if %{with_storage_zfs}
%package daemon-driver-storage-zfs
Summary: Storage driver plugin for ZFS
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
# Support any conforming implementation of zfs
Requires: /sbin/zfs
Requires: /sbin/zpool

%description daemon-driver-storage-zfs
The storage driver backend adding implementation of the storage APIs for
ZFS volumes.
%endif


%package daemon-driver-storage
Summary: Storage driver plugin including all backends for the libvirtd daemon
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-daemon-driver-storage-disk = %{version}-%{release}
Requires: libvirt-daemon-driver-storage-logical = %{version}-%{release}
Requires: libvirt-daemon-driver-storage-scsi = %{version}-%{release}
Requires: libvirt-daemon-driver-storage-iscsi = %{version}-%{release}
Requires: libvirt-daemon-driver-storage-mpath = %{version}-%{release}
%if %{with_storage_iscsi_direct}
Requires: libvirt-daemon-driver-storage-iscsi-direct = %{version}-%{release}
%endif
%if %{with_storage_gluster}
Requires: libvirt-daemon-driver-storage-gluster = %{version}-%{release}
%endif
%if %{with_storage_rbd}
Requires: libvirt-daemon-driver-storage-rbd = %{version}-%{release}
%endif
%if %{with_storage_sheepdog}
Requires: libvirt-daemon-driver-storage-sheepdog = %{version}-%{release}
%endif
%if %{with_storage_zfs}
Requires: libvirt-daemon-driver-storage-zfs = %{version}-%{release}
%endif

%description daemon-driver-storage
The storage driver plugin for the libvirtd daemon, providing
an implementation of the storage APIs using LVM, iSCSI,
parted and more.


%if %{with_qemu}
%package daemon-driver-qemu
Summary: QEMU driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: /usr/bin/qemu-img
# For image compression
Requires: gzip
Requires: bzip2
Requires: lzop
Requires: xz
Requires: systemd-container

%description daemon-driver-qemu
The qemu driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
QEMU
%endif


%if %{with_lxc}
%package daemon-driver-lxc
Summary: LXC driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
# There really is a hard cross-driver dependency here
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: systemd-container

%description daemon-driver-lxc
The LXC driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
the Linux kernel
%endif


%if %{with_vbox}
%package daemon-driver-vbox
Summary: VirtualBox driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-vbox
The vbox driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
VirtualBox
%endif


%if %{with_libxl}
%package daemon-driver-libxl
Summary: Libxl driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Obsoletes: libvirt-daemon-driver-xen < 4.3.0

%description daemon-driver-libxl
The Libxl driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
Libxl
%endif


%if %{with_qemu_tcg}
%package daemon-qemu
Summary: Server side daemon & driver required to run QEMU guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-qemu = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: qemu

%description daemon-qemu
Server side daemon and driver required to manage the virtualization
capabilities of the QEMU TCG emulators
%endif


%if %{with_qemu_kvm}
%package daemon-kvm
Summary: Server side daemon & driver required to run KVM guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-qemu = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: qemu

%description daemon-kvm
Server side daemon and driver required to manage the virtualization
capabilities of the KVM hypervisor
%endif


%if %{with_lxc}
%package daemon-lxc
Summary: Server side daemon & driver required to run LXC guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-lxc = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}

%description daemon-lxc
Server side daemon and driver required to manage the virtualization
capabilities of LXC
%endif


%if %{with_libxl}
%package daemon-xen
Summary: Server side daemon & driver required to run XEN guests

Requires: libvirt-daemon = %{version}-%{release}
    %if %{with_libxl}
Requires: libvirt-daemon-driver-libxl = %{version}-%{release}
    %endif
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: xen

%description daemon-xen
Server side daemon and driver required to manage the virtualization
capabilities of XEN
%endif

%if %{with_vbox}
%package daemon-vbox
Summary: Server side daemon & driver required to run VirtualBox guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-vbox = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}

%description daemon-vbox
Server side daemon and driver required to manage the virtualization
capabilities of VirtualBox
%endif

%package client
Summary: Client side utilities of the libvirt library
Requires: %{name}-libs = %{version}-%{release}
Requires: readline
Requires: ncurses
# Needed by /usr/libexec/libvirt-guests.sh script.
Requires: gettext
# Needed by virt-pki-validate script.
Requires: gnutls-utils
%if %{with_bash_completion}
Requires: %{name}-bash-completion = %{version}-%{release}
%endif

%description client
The client binaries needed to access the virtualization
capabilities of recent versions of Linux (and other OSes).

%package libs
Summary: Client side libraries
# So remote clients can access libvirt over SSH tunnel
Requires: cyrus-sasl
# Needed by default sasl.conf - no onerous extra deps, since
# 100's of other things on a system already pull in krb5-libs
Requires: cyrus-sasl-gssapi

%description libs
Shared libraries for accessing the libvirt daemon.

%package admin
Summary: Set of tools to control libvirt daemon
Requires: %{name}-libs = %{version}-%{release}
Requires: readline
%if %{with_bash_completion}
Requires: %{name}-bash-completion = %{version}-%{release}
%endif

%description admin
The client side utilities to control the libvirt daemon.

%if %{with_bash_completion}
%package bash-completion
Summary: Bash completion script

%description bash-completion
Bash completion script stub.
%endif

%if %{with_wireshark}
%package wireshark
Summary: Wireshark dissector plugin for libvirt RPC transactions
Requires: wireshark >= 2.4.0
Requires: %{name}-libs = %{version}-%{release}

%description wireshark
Wireshark dissector plugin for better analysis of libvirt RPC traffic.
%endif

%if %{with_lxc}
%package login-shell
Summary: Login shell for connecting users to an LXC container
Requires: %{name}-libs = %{version}-%{release}

%description login-shell
Provides the set-uid virt-login-shell binary that is used to
connect a user to an LXC container when they login, by switching
namespaces.
%endif

%package devel
Summary: Libraries, includes, etc. to compile with the libvirt library
Requires: %{name}-libs = %{version}-%{release}
Requires: pkgconfig

%description devel
Include header files & development libraries for the libvirt C library.

%if %{with_sanlock}
%package lock-sanlock
Summary: Sanlock lock manager plugin for QEMU driver
Requires: sanlock >= 2.4
#for virt-sanlock-cleanup require augeas
Requires: augeas
Requires: %{name}-daemon = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}

%description lock-sanlock
Includes the Sanlock lock manager plugin for the QEMU
driver
%endif

%package nss
Summary: Libvirt plugin for Name Service Switch
Requires: libvirt-daemon-driver-network = %{version}-%{release}

%description nss
Libvirt plugin for NSS for translating domain names into IP addresses.


%prep

%autosetup -p1

%build

%if %{with_qemu}
    %define arg_qemu --with-qemu
%else
    %define arg_qemu --without-qemu
%endif

%if %{with_openvz}
    %define arg_openvz --with-openvz
%else
    %define arg_openvz --without-openvz
%endif

%if %{with_lxc}
    %define arg_lxc --with-lxc
    %define arg_login_shell --with-login-shell
%else
    %define arg_lxc --without-lxc
    %define arg_login_shell --without-login-shell
%endif

%if %{with_vbox}
    %define arg_vbox --with-vbox
%else
    %define arg_vbox --without-vbox
%endif

%if %{with_libxl}
    %define arg_libxl --with-libxl
%else
    %define arg_libxl --without-libxl
%endif

%if %{with_esx}
    %define arg_esx --with-esx
%else
    %define arg_esx --without-esx
%endif

%if %{with_hyperv}
    %define arg_hyperv --with-hyperv
%else
    %define arg_hyperv --without-hyperv
%endif

%if %{with_vmware}
    %define arg_vmware --with-vmware
%else
    %define arg_vmware --without-vmware
%endif

%if %{with_storage_rbd}
    %define arg_storage_rbd --with-storage-rbd
%else
    %define arg_storage_rbd --without-storage-rbd
%endif

%if %{with_storage_sheepdog}
    %define arg_storage_sheepdog --with-storage-sheepdog
%else
    %define arg_storage_sheepdog --without-storage-sheepdog
%endif

%if %{with_storage_gluster}
    %define arg_storage_gluster --with-storage-gluster
%else
    %define arg_storage_gluster --without-storage-gluster
%endif

%if %{with_storage_zfs}
    %define arg_storage_zfs --with-storage-zfs
%else
    %define arg_storage_zfs --without-storage-zfs
%endif

%if %{with_numactl}
    %define arg_numactl --with-numactl
%else
    %define arg_numactl --without-numactl
%endif

%if %{with_numad}
    %define arg_numad --with-numad
%else
    %define arg_numad --without-numad
%endif

%if %{with_fuse}
    %define arg_fuse --with-fuse
%else
    %define arg_fuse --without-fuse
%endif

%if %{with_sanlock}
    %define arg_sanlock --with-sanlock
%else
    %define arg_sanlock --without-sanlock
%endif

%if %{with_firewalld}
    %define arg_firewalld --with-firewalld
%else
    %define arg_firewalld --without-firewalld
%endif

%if %{with_firewalld_zone}
    %define arg_firewalld_zone --with-firewalld-zone
%else
    %define arg_firewalld_zone --without-firewalld-zone
%endif

%if %{with_wireshark}
    %define arg_wireshark --with-wireshark-dissector
%else
    %define arg_wireshark --without-wireshark-dissector
%endif

%if %{with_storage_iscsi_direct}
    %define arg_storage_iscsi_direct --with-storage-iscsi-direct
%else
    %define arg_storage_iscsi_direct --without-storage-iscsi-direct
%endif

%define when  %(date +"%%F-%%T")
%define where %(hostname)
%define who   %{?packager}%{!?packager:Unknown}
%define arg_packager --with-packager="%{who}, %{when}, %{where}"
%define arg_packager_version --with-packager-version="%{release}"

%define arg_selinux_mount --with-selinux-mount="/sys/fs/selinux"

# Nightly edk2.git-ovmf-x64
LOADERS="/usr/share/edk2.git/ovmf-x64/OVMF_CODE-pure-efi.fd:/usr/share/edk2.git/ovmf-x64/OVMF_VARS-pure-efi.fd"
# Nightly edk2.git-ovmf-ia32
LOADERS="$LOADERS:/usr/share/edk2.git/ovmf-ia32/OVMF_CODE-pure-efi.fd:/usr/share/edk2.git/ovmf-ia32/OVMF_VARS-pure-efi.fd"
# Nightly edk2.git-aarch64
LOADERS="$LOADERS:/usr/share/edk2.git/aarch64/QEMU_EFI-pflash.raw:/usr/share/edk2.git/aarch64/vars-template-pflash.raw"
# Nightly edk2.git-arm
LOADERS="$LOADERS:/usr/share/edk2.git/arm/QEMU_EFI-pflash.raw:/usr/share/edk2.git/arm/vars-template-pflash.raw"
# Fedora edk2-ovmf
LOADERS="$LOADERS:/usr/share/edk2/ovmf/OVMF_CODE.fd:/usr/share/edk2/ovmf/OVMF_VARS.fd"
# Fedora edk2-ovmf-ia32
LOADERS="$LOADERS:/usr/share/edk2/ovmf-ia32/OVMF_CODE.fd:/usr/share/edk2/ovmf-ia32/OVMF_VARS.fd"
# Fedora edk2-aarch64
LOADERS="$LOADERS:/usr/share/edk2/aarch64/QEMU_EFI-pflash.raw:/usr/share/edk2/aarch64/vars-template-pflash.raw"
# Fedora edk2-arm
LOADERS="$LOADERS:/usr/share/edk2/arm/QEMU_EFI-pflash.raw:/usr/share/edk2/arm/vars-template-pflash.raw"
%define arg_loader_nvram --with-loader-nvram="$LOADERS"

# place macros above and build commands below this comment

export SOURCE_DATE_EPOCH=$(stat --printf='%Y' %{_specdir}/%{name}.spec)

%if 0%{?enable_autotools}
 autoreconf -if
%endif

rm -f po/stamp-po

%define _configure ../configure
mkdir %{_vpath_builddir}
cd %{_vpath_builddir}

%configure --enable-dependency-tracking \
           --with-runstatedir=%{_rundir} \
           %{?arg_qemu} \
           %{?arg_openvz} \
           %{?arg_lxc} \
           %{?arg_vbox} \
           %{?arg_libxl} \
           --with-sasl \
           --with-polkit \
           --with-libvirtd \
           %{?arg_esx} \
           %{?arg_hyperv} \
           %{?arg_vmware} \
           --without-vz \
           --without-bhyve \
           --with-remote-default-mode=legacy \
           --with-interface \
           --with-network \
           --with-storage-fs \
           --with-storage-lvm \
           --with-storage-iscsi \
           %{?arg_storage_iscsi_direct} \
           --with-storage-scsi \
           --with-storage-disk \
           --with-storage-mpath \
           %{?arg_storage_rbd} \
           %{?arg_storage_sheepdog} \
           %{?arg_storage_gluster} \
           %{?arg_storage_zfs} \
           --without-storage-vstorage \
           %{?arg_numactl} \
           %{?arg_numad} \
           --with-capng \
           %{?arg_fuse} \
           --with-netcf \
           --with-selinux \
           %{?arg_selinux_mount} \
           --without-apparmor \
           --without-hal \
           --with-udev \
           --with-yajl \
           %{?arg_sanlock} \
           --with-libpcap \
           --with-macvtap \
           --with-audit \
           %{?arg_dtrace} \
           --with-driver-modules \
           %{?arg_firewalld} \
           %{?arg_firewalld_zone} \
           %{?arg_wireshark} \
           --without-pm-utils \
           --with-nss-plugin \
           %{arg_packager} \
           %{arg_packager_version} \
           --with-qemu-user=%{qemu_user} \
           --with-qemu-group=%{qemu_group} \
           --with-tls-priority=%{tls_priority} \
           %{?arg_loader_nvram} \
           %{?enable_werror} \
           --enable-expensive-tests \
           --with-init-script=systemd \
           %{?arg_login_shell}
make %{?_smp_mflags} V=1

%install
rm -fr %{buildroot}

export SOURCE_DATE_EPOCH=$(stat --printf='%Y' %{_specdir}/%{name}.spec)

cd %{_vpath_builddir}
%make_install %{?_smp_mflags} SYSTEMD_UNIT_DIR=%{_unitdir} V=1

rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/lock-driver/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/lock-driver/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/connection-driver/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/connection-driver/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-backend/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-backend/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-file/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-file/*.a
%if %{with_wireshark}
rm -f $RPM_BUILD_ROOT%{wireshark_plugindir}/libvirt.la
%endif

install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/lib/libvirt/dnsmasq/
# We don't want to install /etc/libvirt/qemu/networks in the main %files list
# because if the admin wants to delete the default network completely, we don't
# want to end up re-incarnating it on every RPM upgrade.
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/
cp $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml \
   $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/default.xml
# libvirt saves this file with mode 0600
chmod 0600 $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml

# nwfilter files are installed in /usr/share/libvirt and copied to /etc in %post
# to avoid verification errors on changed files in /etc
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/libvirt/nwfilter/
cp -a $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/nwfilter/*.xml \
    $RPM_BUILD_ROOT%{_datadir}/libvirt/nwfilter/
# libvirt saves these files with mode 600
chmod 600 $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/nwfilter/*.xml

# Strip auto-generated UUID - we need it generated per-install
sed -i -e "/<uuid>/d" $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/default.xml
%if ! %{with_qemu}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_qemu.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_qemu.aug
%endif
%find_lang %{name}

%if ! %{with_sanlock}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirt_sanlock.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirt_sanlock.aug
%endif

%if ! %{with_lxc}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_lxc.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_lxc.aug
%endif

%if ! %{with_qemu}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu.conf
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.qemu
%endif
%if ! %{with_lxc}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/lxc.conf
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.lxc
%endif
%if ! %{with_libxl}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/libxl.conf
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.libxl
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_libxl.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_libxl.aug
%endif

# Copied into libvirt-docs subpackage eventually
mv $RPM_BUILD_ROOT%{_datadir}/doc/libvirt libvirt-docs

%ifarch %{power64} s390x ia64 alpha sparc64
mv $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_probes.stp \
   $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_probes-64.stp

    %if %{with_qemu}
mv $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_qemu_probes.stp \
   $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_qemu_probes-64.stp
    %endif
%endif

%check
cd %{_vpath_builddir}
if ! make %{?_smp_mflags} check VIR_TEST_DEBUG=1
then
  cat tests/test-suite.log || true
  exit 1
fi

%post libs
/usr/sbin/ldconfig

%postun libs
/usr/sbin/ldconfig

%pre daemon
# 'libvirt' group is just to allow password-less polkit access to
# libvirtd. The uid number is irrelevant, so we use dynamic allocation
# described at the above link.
getent group libvirt >/dev/null || groupadd -r libvirt

exit 0

%post daemon

%systemd_post virtlockd.socket virtlockd-admin.socket
%systemd_post virtlogd.socket virtlogd-admin.socket
%systemd_post libvirtd.socket libvirtd-ro.socket libvirtd-admin.socket
%systemd_post libvirtd-tcp.socket libvirtd-tls.socket
%systemd_post libvirtd.service

# request daemon restart in posttrans
mkdir -p %{_localstatedir}/lib/rpm-state/libvirt || :
touch %{_localstatedir}/lib/rpm-state/libvirt/restart || :

%preun daemon
%systemd_preun libvirtd.service
%systemd_preun libvirtd-tcp.socket libvirtd-tls.socket
%systemd_preun libvirtd.socket libvirtd-ro.socket libvirtd-admin.socket
%systemd_preun virtlogd.socket virtlogd-admin.socket virtlogd.service
%systemd_preun virtlockd.socket virtlockd-admin.socket virtlockd.service

%postun daemon
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ $1 -ge 1 ] ; then
    /bin/systemctl reload-or-try-restart virtlockd.service >/dev/null 2>&1 || :
    /bin/systemctl reload-or-try-restart virtlogd.service >/dev/null 2>&1 || :
fi

# In upgrade scenario we must explicitly enable virtlockd/virtlogd
# sockets, if libvirtd is already enabled and start them if
# libvirtd is running, otherwise you'll get failures to start
# guests
%triggerpostun daemon -- libvirt-daemon < 1.3.0
if [ $1 -ge 1 ] ; then
    /bin/systemctl is-enabled libvirtd.service 1>/dev/null 2>&1 &&
        /bin/systemctl enable virtlogd.socket virtlogd-admin.socket || :
    /bin/systemctl is-active libvirtd.service 1>/dev/null 2>&1 &&
        /bin/systemctl start virtlogd.socket virtlogd-admin.socket || :
fi

%posttrans daemon
if [ -f %{_localstatedir}/lib/rpm-state/libvirt/restart ]; then
    # See if user has previously modified their install to
    # tell libvirtd to use --listen
    grep -E '^LIBVIRTD_ARGS=.*--listen' /etc/sysconfig/libvirtd 1>/dev/null 2>&1
    if test $? = 0
    then
        # Then lets keep honouring --listen and *not* use
        # systemd socket activation, because switching things
        # might confuse mgmt tool like puppet/ansible that
        # expect the old style libvirtd
        /bin/systemctl mask libvirtd.socket >/dev/null 2>&1 || :
        /bin/systemctl mask libvirtd-ro.socket >/dev/null 2>&1 || :
        /bin/systemctl mask libvirtd-admin.socket >/dev/null 2>&1 || :
        /bin/systemctl mask libvirtd-tls.socket >/dev/null 2>&1 || :
        /bin/systemctl mask libvirtd-tcp.socket >/dev/null 2>&1 || :
    else
        # Old libvirtd owns the sockets and will delete them on
        # shutdown. Can't use a try-restart as libvirtd will simply
        # own the sockets again when it comes back up. Thus we must
        # do this particular ordering, so that we get libvirtd
        # running with socket activation in use
        /bin/systemctl is-active libvirtd.service 1>/dev/null 2>&1
        if test $? = 0
        then
            /bin/systemctl stop libvirtd.service >/dev/null 2>&1 || :

            /bin/systemctl try-restart libvirtd.socket >/dev/null 2>&1 || :
            /bin/systemctl try-restart libvirtd-ro.socket >/dev/null 2>&1 || :
            /bin/systemctl try-restart libvirtd-admin.socket >/dev/null 2>&1 || :

            /bin/systemctl start libvirtd.service >/dev/null 2>&1 || :
        fi
    fi
fi
rm -rf %{_localstatedir}/lib/rpm-state/libvirt || :

%post daemon-driver-network
%if %{with_firewalld_zone}
    %firewalld_reload
%endif

%postun daemon-driver-network
%if %{with_firewalld_zone}
    %firewalld_reload
%endif

%post daemon-config-network
if test $1 -eq 1 && test ! -f %{_sysconfdir}/libvirt/qemu/networks/default.xml ; then
    # see if the network used by default network creates a conflict,
    # and try to resolve it
    # NB: 192.168.122.0/24 is used in the default.xml template file;
    # do not modify any of those values here without also modifying
    # them in the template.
    orig_sub=122
    sub=${orig_sub}
    nl='
'
    routes="${nl}$(ip route show | cut -d' ' -f1)${nl}"
    case ${routes} in
      *"${nl}192.168.${orig_sub}.0/24${nl}"*)
        # there was a match, so we need to look for an unused subnet
        for new_sub in $(seq 124 254); do
          case ${routes} in
          *"${nl}192.168.${new_sub}.0/24${nl}"*)
            ;;
          *)
            sub=$new_sub
            break;
            ;;
          esac
        done
        ;;
      *)
        ;;
    esac

    UUID=`/usr/bin/uuidgen`
    sed -e "s/${orig_sub}/${sub}/g" \
        -e "s,</name>,</name>\n  <uuid>$UUID</uuid>," \
         < %{_datadir}/libvirt/networks/default.xml \
         > %{_sysconfdir}/libvirt/qemu/networks/default.xml
    ln -s ../default.xml %{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml
    # libvirt saves this file with mode 0600
    chmod 0600 %{_sysconfdir}/libvirt/qemu/networks/default.xml

    # Make sure libvirt picks up the new network defininiton
    mkdir -p %{_localstatedir}/lib/rpm-state/libvirt || :
    touch %{_localstatedir}/lib/rpm-state/libvirt/restart || :
fi

%posttrans daemon-config-network
if [ -f %{_localstatedir}/lib/rpm-state/libvirt/restart ]; then
    /bin/systemctl try-restart libvirtd.service >/dev/null 2>&1 || :
fi
rm -rf %{_localstatedir}/lib/rpm-state/libvirt || :

%post daemon-config-nwfilter
cp %{_datadir}/libvirt/nwfilter/*.xml %{_sysconfdir}/libvirt/nwfilter/
# libvirt saves these files with mode 600
chmod 600 %{_sysconfdir}/libvirt/nwfilter/*.xml
# Make sure libvirt picks up the new nwfilter defininitons
mkdir -p %{_localstatedir}/lib/rpm-state/libvirt || :
touch %{_localstatedir}/lib/rpm-state/libvirt/restart || :

%posttrans daemon-config-nwfilter
if [ -f %{_localstatedir}/lib/rpm-state/libvirt/restart ]; then
    /bin/systemctl try-restart libvirtd.service >/dev/null 2>&1 || :
fi
rm -rf %{_localstatedir}/lib/rpm-state/libvirt || :


%if %{with_qemu}
%pre daemon-driver-qemu
# We want soft static allocation of well-known ids, as disk images
# are commonly shared across NFS mounts by id rather than name; see
# https://fedoraproject.org/wiki/Packaging:UsersAndGroups
getent group kvm >/dev/null || groupadd -f -g 36 -r kvm
getent group qemu >/dev/null || groupadd -f -g 107 -r qemu
if ! getent passwd qemu >/dev/null; then
  if ! getent passwd 107 >/dev/null; then
    useradd -r -u 107 -g qemu -G kvm -d / -s /sbin/nologin -c "qemu user" qemu
  else
    useradd -r -g qemu -G kvm -d / -s /sbin/nologin -c "qemu user" qemu
  fi
fi
exit 0
%endif

%preun client

%systemd_preun libvirt-guests.service

%post client
%systemd_post libvirt-guests.service

%postun client
%systemd_postun libvirt-guests.service

%if %{with_lxc}
%pre login-shell
getent group virtlogin >/dev/null || groupadd -r virtlogin
exit 0
%endif

%files

%files docs
%doc AUTHORS ChangeLog NEWS README README.md
%doc %{_vpath_builddir}/libvirt-docs/*

%files daemon

%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/

%{_unitdir}/libvirtd.service
%{_unitdir}/libvirtd.socket
%{_unitdir}/libvirtd-ro.socket
%{_unitdir}/libvirtd-admin.socket
%{_unitdir}/libvirtd-tcp.socket
%{_unitdir}/libvirtd-tls.socket
%{_unitdir}/virtproxyd.service
%{_unitdir}/virtproxyd.socket
%{_unitdir}/virtproxyd-ro.socket
%{_unitdir}/virtproxyd-admin.socket
%{_unitdir}/virtproxyd-tcp.socket
%{_unitdir}/virtproxyd-tls.socket
%{_unitdir}/virt-guest-shutdown.target
%{_unitdir}/virtlogd.service
%{_unitdir}/virtlogd.socket
%{_unitdir}/virtlogd-admin.socket
%{_unitdir}/virtlockd.service
%{_unitdir}/virtlockd.socket
%{_unitdir}/virtlockd-admin.socket
%config(noreplace) %{_sysconfdir}/sysconfig/libvirtd
%config(noreplace) %{_sysconfdir}/sysconfig/virtlogd
%config(noreplace) %{_sysconfdir}/sysconfig/virtlockd
%config(noreplace) %{_sysconfdir}/libvirt/libvirtd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtproxyd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtlogd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtlockd.conf
%config(noreplace) %{_sysconfdir}/sasl2/libvirt.conf
%config(noreplace) %{_prefix}/lib/sysctl.d/60-libvirtd.conf

%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd
%dir %{_datadir}/libvirt/

%ghost %dir %{_rundir}/libvirt/

%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/images/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/filesystems/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/boot/
%dir %attr(0711, root, root) %{_localstatedir}/cache/libvirt/


%dir %attr(0755, root, root) %{_libdir}/libvirt/
%dir %attr(0755, root, root) %{_libdir}/libvirt/connection-driver/
%dir %attr(0755, root, root) %{_libdir}/libvirt/lock-driver
%attr(0755, root, root) %{_libdir}/libvirt/lock-driver/lockd.so

%{_datadir}/augeas/lenses/libvirtd.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd.aug
%{_datadir}/augeas/lenses/virtlogd.aug
%{_datadir}/augeas/lenses/tests/test_virtlogd.aug
%{_datadir}/augeas/lenses/virtlockd.aug
%{_datadir}/augeas/lenses/tests/test_virtlockd.aug
%{_datadir}/augeas/lenses/virtproxyd.aug
%{_datadir}/augeas/lenses/tests/test_virtproxyd.aug
%{_datadir}/augeas/lenses/libvirt_lockd.aug
%if %{with_qemu}
%{_datadir}/augeas/lenses/tests/test_libvirt_lockd.aug
%endif

%{_datadir}/polkit-1/actions/org.libvirt.unix.policy
%{_datadir}/polkit-1/actions/org.libvirt.api.policy
%{_datadir}/polkit-1/rules.d/50-libvirt.rules

%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/

%attr(0755, root, root) %{_libexecdir}/libvirt_iohelper

%attr(0755, root, root) %{_sbindir}/libvirtd
%attr(0755, root, root) %{_sbindir}/virtproxyd
%attr(0755, root, root) %{_sbindir}/virtlogd
%attr(0755, root, root) %{_sbindir}/virtlockd

%{_mandir}/man8/libvirtd.8*
%{_mandir}/man8/virtlogd.8*
%{_mandir}/man8/virtlockd.8*
%{_mandir}/man7/virkey*.7*

%files daemon-config-network
%dir %{_datadir}/libvirt/networks/
%{_datadir}/libvirt/networks/default.xml
%ghost %{_sysconfdir}/libvirt/qemu/networks/default.xml
%ghost %{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml

%files daemon-config-nwfilter
%dir %{_datadir}/libvirt/nwfilter/
%{_datadir}/libvirt/nwfilter/*.xml
%ghost %{_sysconfdir}/libvirt/nwfilter/*.xml

%files daemon-driver-interface
%config(noreplace) %{_sysconfdir}/libvirt/virtinterfaced.conf
%{_datadir}/augeas/lenses/virtinterfaced.aug
%{_datadir}/augeas/lenses/tests/test_virtinterfaced.aug
%{_unitdir}/virtinterfaced.service
%{_unitdir}/virtinterfaced.socket
%{_unitdir}/virtinterfaced-ro.socket
%{_unitdir}/virtinterfaced-admin.socket
%attr(0755, root, root) %{_sbindir}/virtinterfaced
%{_libdir}/%{name}/connection-driver/libvirt_driver_interface.so

%files daemon-driver-network
%config(noreplace) %{_sysconfdir}/libvirt/virtnetworkd.conf
%{_datadir}/augeas/lenses/virtnetworkd.aug
%{_datadir}/augeas/lenses/tests/test_virtnetworkd.aug
%{_unitdir}/virtnetworkd.service
%{_unitdir}/virtnetworkd.socket
%{_unitdir}/virtnetworkd-ro.socket
%{_unitdir}/virtnetworkd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtnetworkd
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/autostart
%ghost %dir %{_rundir}/libvirt/network/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/network/
%dir %attr(0755, root, root) %{_localstatedir}/lib/libvirt/dnsmasq/
%attr(0755, root, root) %{_libexecdir}/libvirt_leaseshelper
%{_libdir}/%{name}/connection-driver/libvirt_driver_network.so

%if %{with_firewalld_zone}
%{_prefix}/lib/firewalld/zones/libvirt.xml
%endif

%files daemon-driver-nodedev
%config(noreplace) %{_sysconfdir}/libvirt/virtnodedevd.conf
%{_datadir}/augeas/lenses/virtnodedevd.aug
%{_datadir}/augeas/lenses/tests/test_virtnodedevd.aug
%{_unitdir}/virtnodedevd.service
%{_unitdir}/virtnodedevd.socket
%{_unitdir}/virtnodedevd-ro.socket
%{_unitdir}/virtnodedevd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtnodedevd
%{_libdir}/%{name}/connection-driver/libvirt_driver_nodedev.so

%files daemon-driver-nwfilter
%config(noreplace) %{_sysconfdir}/libvirt/virtnwfilterd.conf
%{_datadir}/augeas/lenses/virtnwfilterd.aug
%{_datadir}/augeas/lenses/tests/test_virtnwfilterd.aug
%{_unitdir}/virtnwfilterd.service
%{_unitdir}/virtnwfilterd.socket
%{_unitdir}/virtnwfilterd-ro.socket
%{_unitdir}/virtnwfilterd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtnwfilterd
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/nwfilter/
%ghost %dir %{_rundir}/libvirt/network/
%{_libdir}/%{name}/connection-driver/libvirt_driver_nwfilter.so

%files daemon-driver-secret
%config(noreplace) %{_sysconfdir}/libvirt/virtsecretd.conf
%{_datadir}/augeas/lenses/virtsecretd.aug
%{_datadir}/augeas/lenses/tests/test_virtsecretd.aug
%{_unitdir}/virtsecretd.service
%{_unitdir}/virtsecretd.socket
%{_unitdir}/virtsecretd-ro.socket
%{_unitdir}/virtsecretd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtsecretd
%{_libdir}/%{name}/connection-driver/libvirt_driver_secret.so

%files daemon-driver-storage

%files daemon-driver-storage-core
%config(noreplace) %{_sysconfdir}/libvirt/virtstoraged.conf
%{_datadir}/augeas/lenses/virtstoraged.aug
%{_datadir}/augeas/lenses/tests/test_virtstoraged.aug
%{_unitdir}/virtstoraged.service
%{_unitdir}/virtstoraged.socket
%{_unitdir}/virtstoraged-ro.socket
%{_unitdir}/virtstoraged-admin.socket
%attr(0755, root, root) %{_sbindir}/virtstoraged
%attr(0755, root, root) %{_libexecdir}/libvirt_parthelper
%{_libdir}/%{name}/connection-driver/libvirt_driver_storage.so
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_fs.so
%{_libdir}/%{name}/storage-file/libvirt_storage_file_fs.so

%files daemon-driver-storage-disk
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_disk.so

%files daemon-driver-storage-logical
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_logical.so

%files daemon-driver-storage-scsi
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_scsi.so

%files daemon-driver-storage-iscsi
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_iscsi.so

%if %{with_storage_iscsi_direct}
%files daemon-driver-storage-iscsi-direct
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_iscsi-direct.so
%endif

%files daemon-driver-storage-mpath
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_mpath.so

%if %{with_storage_gluster}
%files daemon-driver-storage-gluster
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_gluster.so
%{_libdir}/%{name}/storage-file/libvirt_storage_file_gluster.so
%endif

%if %{with_storage_rbd}
%files daemon-driver-storage-rbd
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_rbd.so
%endif

%if %{with_storage_sheepdog}
%files daemon-driver-storage-sheepdog
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_sheepdog.so
%endif

%if %{with_storage_zfs}
%files daemon-driver-storage-zfs
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_zfs.so
%endif

%if %{with_qemu}
%files daemon-driver-qemu
%config(noreplace) %{_sysconfdir}/libvirt/virtqemud.conf
%{_datadir}/augeas/lenses/virtqemud.aug
%{_datadir}/augeas/lenses/tests/test_virtqemud.aug
%{_unitdir}/virtqemud.service
%{_unitdir}/virtqemud.socket
%{_unitdir}/virtqemud-ro.socket
%{_unitdir}/virtqemud-admin.socket
%attr(0755, root, root) %{_sbindir}/virtqemud
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/qemu/
%config(noreplace) %{_sysconfdir}/libvirt/qemu.conf
%config(noreplace) %{_sysconfdir}/libvirt/qemu-lockd.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.qemu
%ghost %dir %{_rundir}/libvirt/qemu/
%dir %attr(0751, %{qemu_user}, %{qemu_group}) %{_localstatedir}/lib/libvirt/qemu/
%dir %attr(0750, %{qemu_user}, %{qemu_group}) %{_localstatedir}/cache/libvirt/qemu/
%{_datadir}/augeas/lenses/libvirtd_qemu.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_qemu.aug
%{_libdir}/%{name}/connection-driver/libvirt_driver_qemu.so
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/swtpm/
%dir %attr(0711, root, root) %{_localstatedir}/log/swtpm/libvirt/qemu/
%{_bindir}/virt-qemu-run
%{_mandir}/man1/virt-qemu-run.1*
%endif

%if %{with_lxc}
%files daemon-driver-lxc
%config(noreplace) %{_sysconfdir}/libvirt/virtlxcd.conf
%{_datadir}/augeas/lenses/virtlxcd.aug
%{_datadir}/augeas/lenses/tests/test_virtlxcd.aug
%{_unitdir}/virtlxcd.service
%{_unitdir}/virtlxcd.socket
%{_unitdir}/virtlxcd-ro.socket
%{_unitdir}/virtlxcd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtlxcd
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/lxc/
%config(noreplace) %{_sysconfdir}/libvirt/lxc.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.lxc
%ghost %dir %{_rundir}/libvirt/lxc/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/lxc/
%{_datadir}/augeas/lenses/libvirtd_lxc.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_lxc.aug
%attr(0755, root, root) %{_libexecdir}/libvirt_lxc
%{_libdir}/%{name}/connection-driver/libvirt_driver_lxc.so
%endif

%if %{with_libxl}
%files daemon-driver-libxl
%config(noreplace) %{_sysconfdir}/libvirt/virtxend.conf
%{_datadir}/augeas/lenses/virtxend.aug
%{_datadir}/augeas/lenses/tests/test_virtxend.aug
%{_unitdir}/virtxend.service
%{_unitdir}/virtxend.socket
%{_unitdir}/virtxend-ro.socket
%{_unitdir}/virtxend-admin.socket
%attr(0755, root, root) %{_sbindir}/virtxend
%config(noreplace) %{_sysconfdir}/libvirt/libxl.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.libxl
%config(noreplace) %{_sysconfdir}/libvirt/libxl-lockd.conf
%{_datadir}/augeas/lenses/libvirtd_libxl.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_libxl.aug
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/libxl/
%ghost %dir %{_rundir}/libvirt/libxl/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/libxl/
%{_libdir}/%{name}/connection-driver/libvirt_driver_libxl.so
%endif

%if %{with_vbox}
%files daemon-driver-vbox
%config(noreplace) %{_sysconfdir}/libvirt/virtvboxd.conf
%{_datadir}/augeas/lenses/virtvboxd.aug
%{_datadir}/augeas/lenses/tests/test_virtvboxd.aug
%{_unitdir}/virtvboxd.service
%{_unitdir}/virtvboxd.socket
%{_unitdir}/virtvboxd-ro.socket
%{_unitdir}/virtvboxd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtvboxd
%{_libdir}/%{name}/connection-driver/libvirt_driver_vbox.so
%endif

%if %{with_qemu_tcg}
%files daemon-qemu
%endif

%if %{with_qemu_kvm}
%files daemon-kvm
%endif

%if %{with_lxc}
%files daemon-lxc
%endif

%if %{with_libxl}
%files daemon-xen
%endif

%if %{with_vbox}
%files daemon-vbox
%endif

%if %{with_sanlock}
%files lock-sanlock
    %if %{with_qemu}
%config(noreplace) %{_sysconfdir}/libvirt/qemu-sanlock.conf
    %endif
    %if %{with_libxl}
%config(noreplace) %{_sysconfdir}/libvirt/libxl-sanlock.conf
    %endif
%attr(0755, root, root) %{_libdir}/libvirt/lock-driver/sanlock.so
%{_datadir}/augeas/lenses/libvirt_sanlock.aug
%{_datadir}/augeas/lenses/tests/test_libvirt_sanlock.aug
%dir %attr(0770, root, sanlock) %{_localstatedir}/lib/libvirt/sanlock
%{_sbindir}/virt-sanlock-cleanup
%{_mandir}/man8/virt-sanlock-cleanup.8*
%attr(0755, root, root) %{_libexecdir}/libvirt_sanlock_helper
%endif

%files client
%{_mandir}/man1/virsh.1*
%{_mandir}/man1/virt-xml-validate.1*
%{_mandir}/man1/virt-pki-validate.1*
%{_mandir}/man1/virt-host-validate.1*
%{_bindir}/virsh
%{_bindir}/virt-xml-validate
%{_bindir}/virt-pki-validate
%{_bindir}/virt-host-validate

%ifnarch aarch64 x86_64
    %{_datadir}/systemtap/tapset/libvirt_probes*.stp
    %{_datadir}/systemtap/tapset/libvirt_functions.stp
    %if %{with_qemu}
    %{_datadir}/systemtap/tapset/libvirt_qemu_probes*.stp
    %endif
%endif

%if %{with_bash_completion}
%{_datadir}/bash-completion/completions/virsh
%endif


%{_unitdir}/libvirt-guests.service
%config(noreplace) %{_sysconfdir}/sysconfig/libvirt-guests
%attr(0755, root, root) %{_libexecdir}/libvirt-guests.sh

%files libs -f %{_vpath_builddir}/%{name}.lang
%license COPYING COPYING.LESSER
%config(noreplace) %{_sysconfdir}/libvirt/libvirt.conf
%config(noreplace) %{_sysconfdir}/libvirt/libvirt-admin.conf
%{_libdir}/libvirt.so.*
%{_libdir}/libvirt-qemu.so.*
%{_libdir}/libvirt-lxc.so.*
%{_libdir}/libvirt-admin.so.*
%dir %{_datadir}/libvirt/
%dir %{_datadir}/libvirt/schemas/
%dir %attr(0755, root, root) %{_localstatedir}/lib/libvirt/

%{_datadir}/libvirt/schemas/basictypes.rng
%{_datadir}/libvirt/schemas/capability.rng
%{_datadir}/libvirt/schemas/cputypes.rng
%{_datadir}/libvirt/schemas/domain.rng
%{_datadir}/libvirt/schemas/domainbackup.rng
%{_datadir}/libvirt/schemas/domaincaps.rng
%{_datadir}/libvirt/schemas/domaincheckpoint.rng
%{_datadir}/libvirt/schemas/domaincommon.rng
%{_datadir}/libvirt/schemas/domainsnapshot.rng
%{_datadir}/libvirt/schemas/interface.rng
%{_datadir}/libvirt/schemas/network.rng
%{_datadir}/libvirt/schemas/networkcommon.rng
%{_datadir}/libvirt/schemas/networkport.rng
%{_datadir}/libvirt/schemas/nodedev.rng
%{_datadir}/libvirt/schemas/nwfilter.rng
%{_datadir}/libvirt/schemas/nwfilter_params.rng
%{_datadir}/libvirt/schemas/nwfilterbinding.rng
%{_datadir}/libvirt/schemas/secret.rng
%{_datadir}/libvirt/schemas/storagecommon.rng
%{_datadir}/libvirt/schemas/storagepool.rng
%{_datadir}/libvirt/schemas/storagepoolcaps.rng
%{_datadir}/libvirt/schemas/storagevol.rng

%{_datadir}/libvirt/cpu_map/*.xml

%{_datadir}/libvirt/test-screenshot.png

%files admin
%{_mandir}/man1/virt-admin.1*
%{_bindir}/virt-admin
%if %{with_bash_completion}
%{_datadir}/bash-completion/completions/virt-admin
%endif

%if %{with_bash_completion}
%files bash-completion
%{_datadir}/bash-completion/completions/vsh
%endif

%if %{with_wireshark}
%files wireshark
%{wireshark_plugindir}/libvirt.so
%endif

%files nss
%{_libdir}/libnss_libvirt.so.2
%{_libdir}/libnss_libvirt_guest.so.2

%if %{with_lxc}
%files login-shell
%attr(4750, root, virtlogin) %{_bindir}/virt-login-shell
%{_libexecdir}/virt-login-shell-helper
%config(noreplace) %{_sysconfdir}/libvirt/virt-login-shell.conf
%{_mandir}/man1/virt-login-shell.1*
%endif

%files devel
%{_libdir}/libvirt.so
%{_libdir}/libvirt-admin.so
%{_libdir}/libvirt-qemu.so
%{_libdir}/libvirt-lxc.so
%dir %{_includedir}/libvirt
%{_includedir}/libvirt/virterror.h
%{_includedir}/libvirt/libvirt.h
%{_includedir}/libvirt/libvirt-admin.h
%{_includedir}/libvirt/libvirt-common.h
%{_includedir}/libvirt/libvirt-domain.h
%{_includedir}/libvirt/libvirt-domain-checkpoint.h
%{_includedir}/libvirt/libvirt-domain-snapshot.h
%{_includedir}/libvirt/libvirt-event.h
%{_includedir}/libvirt/libvirt-host.h
%{_includedir}/libvirt/libvirt-interface.h
%{_includedir}/libvirt/libvirt-network.h
%{_includedir}/libvirt/libvirt-nodedev.h
%{_includedir}/libvirt/libvirt-nwfilter.h
%{_includedir}/libvirt/libvirt-secret.h
%{_includedir}/libvirt/libvirt-storage.h
%{_includedir}/libvirt/libvirt-stream.h
%{_includedir}/libvirt/libvirt-qemu.h
%{_includedir}/libvirt/libvirt-lxc.h
%{_libdir}/pkgconfig/libvirt.pc
%{_libdir}/pkgconfig/libvirt-admin.pc
%{_libdir}/pkgconfig/libvirt-qemu.pc
%{_libdir}/pkgconfig/libvirt-lxc.pc

%dir %{_datadir}/libvirt/api/
%{_datadir}/libvirt/api/libvirt-api.xml
%{_datadir}/libvirt/api/libvirt-admin-api.xml
%{_datadir}/libvirt/api/libvirt-qemu-api.xml
%{_datadir}/libvirt/api/libvirt-lxc-api.xml


%changelog
* Sat Dec 17 2022 zhengchuan <zhengchuan@huawei.com> - 6.2.0-49
- add function of set migration thread affinity during migration

* Sat Dec 10 2022 yezengruan <yezengruan@huawei.com> - 6.2.0-48
- update the Chinese translation of nwfilter

* Tue Dec 06 2022 yezengruan <yezengruan@huawei.com> - 6.2.0-47
- sync some bugfix patches from upstream
- support vhostuser disk
- libvirt: support dirtyrate (calc-dirty-rate, dirtyrate-param.mode)

* Fri Nov 25 2022 yezengruan <yezengruan@huawei.com> - 6.2.0-46
- sync some bugfix patches from upstream

* Fri Nov 11 2022 yezengruan <yezengruan@huawei.com> - 6.2.0-45
- docs: Fix template matching in page.xsl

* Thu Nov 03 2022 yezengruan <yezengruan@huawei.com> - 6.2.0-44
- libvirt: support migration dirtyrate

* Tue Oct 11 2022 wengyu <wengyu@isrc.iscas.ac.cn> - 6.2.0-43
- libvirt: Synchronize upstream patches according to issue I5OLYY

* Thu Aug 25 2022 yezengruan <yezengruan@huawei.com> - 6.2.0-42
- qemu: Add missing lock in qemuProcessHandleMonitorEOF (CVE-2021-3975)

* Thu Aug 11 2022 yezengruan <yezengruan@huawei.com> - 6.2.0-41
- apibuild: Fix self.waring method call

* Mon Jun 20 2022 yezengruan <yezengruan@huawei.com> - 6.2.0-40
- nwfilter: fix crash when counting number of network filters (CVE-2022-0897)

* Mon Jun 13 2022 yezengruan <yezengruan@huawei.com> - 6.2.0-39
- sw_64: Add sw64 architecture support
- src: workaround warning triggered in glib 2.69

* Tue May 10 2022 yezengruan <yezengruan@huawei.com> - 6.2.0-38
- update some inconsistent patches
- virsh: Display vhostuser socket path in domblklist

* Wed Apr 27 2022 yezengruan <yezengruan@huawei.com> - 6.2.0-37
- update the format of changelog

* Thu Mar 24 2022 yezengruan <yezengruan@huawei.com> - 6.2.0-36
- apparmor: Permit new capabilities required by libvirtd

* Thu Mar 24 2022 yezengruan <yezengruan@huawei.com> - 6.2.0-35
- qemuMonitorJSONSetMigrationParams: Take double pointer for @params
- qemuMonitorJSONAddObject: Take double pointer for @props
- :qemuMonitorJSONMakeCommandInternal: Clear @arguments when stolen
- qemuMonitorAddObject: Fix semantics of @alias
- qemuMonitorAddObject: Refactor cleanup
- util: json: Replace virJSONValueObjectSteal by virJSONValueObjectRemoveKey
- qemu: command: Generate commandline of 'masterKey0' secret via JSON
- qemu: command: Generate commandline of 'sev0' sev-guest object via JSON
- qemu: command: Generate commandline of iothread objects JSON
- qemu: capabilities: Introduce QEMU_CAPS_OBJECT_QAPIFIED
- qemu: monitor: Make wrapping of 'props' of 'object-add' optional
- qemuMonitorCreateObjectPropsWrap: Open-code in qemuBuildMemoryBackendProps
- qemu: monitor: Don't add 'props' wrapper if qemu has QEMU_CAPS_OBJECT_QAPIFIED
- qemu: command: Use JSON for QAPIfied -object directly
- tests: qemuxml2argv: Validate generation of JSON props for object-add
- qemu: capabilities: Enable detection of QEMU_CAPS_OBJECT_QAPIFIED

* Sat Mar 12 2022 yezengruan <yezengruan@huawei.com> - 6.2.0-34
- Revert libvirt: support aarch64 vtpm with parameter tpm-tis-device
- qemu: Fix swtpm device with aarch64
- qemu: Fix libvirt hang due to early TPM device stop
- qemu_tpm: Move logfile path generation into a separate function
- qemu_tpm: Generate log file path among with storage path
- virtpm: Fix @path handling in virTPMEmulatorInit()

* Fri Mar 11 2022 yezengruan <yezengruan@huawei.com> - 6.2.0-33
- qemu: Probe for a few params supported by migrate-set-parameters
- qemu: Avoid deprecated migrate_set_speed QMP command
- qemu: Avoid deprecated migrate_set_downtime QMP command
- qemu: Avoid deprecated query-migrate-cache-size QMP command
- qemu: Avoid deprecated migrate-set-cache-size QMP command
- qemu: Track numa-mem-supported machine attribute
- qemuBuildNumaArgStr: Switch order of if() and for()
- qemuBuildNumaArgStr: Use modern -numa memdev= if old -numa mem= is unsupported

* Mon Feb 21 2022 imxcc <xingchaochao@huawei.com> - 6.2.0-32
- virQEMUBuildCommandLineJSON: Allow skipping certain keys
- virQEMUBuildCommandLineJSON: Add possibility for using 'on/off' instead of 'yes/no'
- util: virqemu: Introduce virQEMUBuildNetdevCommandlineFromJSON
- util: json: Introduce virJSONValueObjectAppendStringPrintf
- qemuBuildChannelsCommandLine: Use typecasted switch for channel type
- qemuBuildChannelsCommandLine: Extract common formatting of 'chardev'
- qemuBuildChannelChrDeviceStr: Remove formatting of properties for -netdev
- qemuMonitorJSON(Add|Remove)Netdev: Refactor cleanup
- qemuBuildHostNetStr: Stop using 'ipv6-net' convenience argument
- qemu: command: Generate -netdev command line via JSON->cmdline conversion
- qemuBuildChannelGuestfwdNetdevProps: Convert to generating JSON props
- qemuMonitorAddNetdev: Convert to the native JSON props object
- virCommand: Introduce virCommandGetArgList
- testutilsqemuschema: Introduce testQEMUSchemaValidateCommand
- testCompareXMLToArgv: Split out preparation and command formatting
- virQEMUBuildNetdevCommandlineFromJSON: Prepare for quirky 'guestfwd'
- qemu: Prepare for testing of 'netdev_add' props via qemuxml2argvtest
- qemuxml2argvtest: Add QAPI/QMP schema validation for -blockdev and -netdev

* Sat Feb 12 2022 imxcc <xingchaochao@huawei.com> - 6.2.0-31
- hotpatch: virsh support autoload mode

* Sat Jan 29 2022 imxcc <xingchaochao@huawei.com> - 6.2.0-30
- Revert "tests: disabale storage tests"

* Fri Jan 14 2022 imxcc <xingchaochao@huawei.com> - 6.2.0-29
- tests: disabale storage tests

* Tue Jan 11 2022 imxcc <xingchaochao@huawei.com> - 6.2.0-28
- docs: build: Don't include stylesheet in intermediate html
- tests: Replace deprecated ASN1 code

* Mon Dec 06 2021 Euler Robot <euler.robot@huawei.com> - 6.2.0-27
- hotpatch: implement hotpatch virsh api
- hotpatch: check vm id and pid before using hotpatch api
- domain: add logs for virDomainHotpatchManage

* Mon Dec 06 2021 Euler Robot <euler.robot@huawei.com> - 6.2.0-26
- Hotpatch: introduce DomainHotpatchManage API
- hotpatch: Implement qemuDomainHotpatchManage
- hotpatch: introduce hotpatch async job flag

* Sun Sep 26 2021 imxcc <xingchaochao@huawei.com> - 6.2.0-26
- fix cve-2021-3667 cve-2021-3631

* Fri Sep 24 2021 Euler Robot <euler.robot@huawei.com> - 6.2.0-25
- conf/domain_conf: pin the retry_interval and retry_timeout parameters to xml

* Tue Sep 14 2021 imxcc <xingchaochao@huawei.com> - 6.2.0-24
- virDevMapperGetTargets: Don't ignore EBADF

* Tue Sep 14 2021 imxcc <xingchaochao@huawei.com> - 6.2.0-23
- Modify some different patch files

* Thu Sep 2 2021 heyitao <heyitao@uniontech.com> - 6.2.0-22
- Don't cache device-mapper major
- Handle kernel without device-mapper support

* Fri Jul 30 2021 chenyanpanHW <chenyanpan@huawei.com> - 6.2.0-21
- DESC: delete -S git_am from %autosetup, and delete BuildRequires git

* Tue Jul 27 2021 Jingyi Wang <wangjingyi11@huawei.com> - 6.2.0-20
- add new CPU model Cooperlake

* Tue Jul 13 2021 imxcc <xingchaochao@huawei.com> - 6.2.0-19
- tests: fix stat mocking with Fedora rawhide

* Fri Mar 19 2021 Jiajie Li <lijiajie11@huawei.com> - 6.2.0-18
- libvirt.spec: remove dtrace for aarch64 OS

* Thu Mar 18 2021 Chen Qun <kuhn.chenqun@huawei.com> - 6.2.0-17
- libvirt/conf: Set default values of retry fileds

* Sat Feb 27 2021 Huawei Technologies Co., Ltd <alex.chen@huawei.com>  - 6.2.0-16
- add phytium 2000plus and s2500 support on arm architecture for capability

* Sat Feb 27 2021 Huawei Technologies Co., Ltd <alex.chen@huawei.com>  - 6.2.0-15
- libvirt: Add 'retry' support for error policy
- qemu: Support 'retry' BLOCK_IO_ERROR event.

* Wed Jan 20 2021 Huawei Technologies Co., Ltd <alex.chen@huawei.com>  - 6.2.0-15
- util: Move virIsDevMapperDevice() to virdevmapper.c
- virdevmapper: Don't use libdevmapper to obtain dependencies

* Wed Oct 14 2020 Huawei Technologies Co., Ltd <alex.chen@huawei.com>  - 6.2.0-14
- rpc: gendispatch: handle empty flags
- rpc: add support for filtering @acls by uint params
- rpc: require write acl for guest agent in virDomainInterfaceAddresses
- qemu: agent: set ifname to NULL after freeing

* Tue Sep 22 2020 AlexChen <alex.chen@huawei.com> - 6.2.0-13
- bugfix: cherry-pick some bugfix patches from opensource community

* Tue Sep 22 2020 Hao Wang <wanghao232@huawei.com> - 6.2.0-12
- backport upstream patches

* Tue Sep 22 2020 Zeyu Jin <jinzeyu@huawei.com> - 6.2.0-11
- bugfix: backport an upstream patch to fix '/run/libvirt/qemu/dbus' racing bug.

* Tue Sep 22 2020 Jin Yan <jinyan12@huawei.com> - 6.2.0-10
- bugfix: cherry-pick some bugfix patches from opensource community

* Wed Aug 5 2020 AlexChen <alex.chen@huawei.com> - 6.2.0-9
- tests: skip the test4 if the testcase is run in the container env

* Wed Aug 5 2020 Jiang Fangjie <jiangfangjie@huawei.com> - 6.2.0-8
- Libvirt supports aarch64 vtpm with parameter tpm-tis-device

* Tue Aug 4 2020 Xu Yandong <xuyandong2@huawei.com> - 6.2.0-7
- Substitute security_context_t with char pointer.

* Tue May 26 2020 Xu Yandong <xuyandong2@huawei.com> - 6.2.0-6
- Introduce Kunpeng-920 cpu features.

* Wed May 20 2020 Xu Yandong <xuyandong2@huawei.com> - 6.2.0-5
- Enable 'host-model' cpu mode.

* Mon May 11 2020 Xu Yandong <xuyandong2@huawei.com> - 6.2.0-4
- Fix virdaemon waiting for child processes return code error.
- Fix virsh dump and migrate return code error.

* Mon May 11 2020 Xu Yandong <xuyandong2@huawei.com> - 6.2.0-3
- Checkout cpu capabilities support for ARM architecture.
- Support Kunpeng-920 CPU.

* Mon Apr 20 2020 Xu Yandong <xuyandong2@huawei.com> - 6.2.0-2
- Checkout bugfixs from 5.5.0 release.

* Tue Apr 14 2020 Xu Yandong <xuyandong2@huawei.com> - 6.2.0-1
- Rebase to version 6.2.0.

* Fri Jul 19 2019 openEuler Buildteam <buildteam@openeuler.org> - 5.5.0-1
- Update to 5.5.0 release, Initial package for openEuler.
